diff include/freeDiameter/libfdproto.h @ 1019:6fcd30ce3ce7

Retrieve additional information when adding a routing error
author Sebastien Decugis <sdecugis@freediameter.net>
date Mon, 01 Apr 2013 16:16:28 +0800
parents 908ffbb81f60
children afaeef21596b
line wrap: on
line diff
--- a/include/freeDiameter/libfdproto.h	Mon Apr 01 16:14:35 2013 +0800
+++ b/include/freeDiameter/libfdproto.h	Mon Apr 01 16:16:28 2013 +0800
@@ -2047,12 +2047,12 @@
 /* Extract the list of valid candidates, and initialize their scores to 0 */
 void fd_rtd_candidate_extract(struct rt_data * rtd, struct fd_list ** candidates, int ini_score);
 
-/* If a peer returned a protocol error for this message, save it so that we don't try to send it there again */
-int  fd_rtd_error_add(struct rt_data * rtd, DiamId_t sentto, size_t senttolen, uint8_t * origin, size_t originsz, uint32_t rcode);
+/* If a peer returned a protocol error for this message, save it so that we don't try to send it there again. Optionally retrieve the current list of candidates. */
+int  fd_rtd_error_add(struct rt_data * rtd, DiamId_t sentto, size_t senttolen, uint8_t * origin, size_t originsz, uint32_t rcode, struct fd_list ** candidates, int * sendingattemtps);
 
 /* The extracted list items have the following structure: */
 struct rtd_candidate {
-	struct fd_list	chain;	/* link in the list returned by the previous fct */
+	struct fd_list	chain;	/* link in the list returned by the previous fcts */
 	DiamId_t	diamid;	/* the diameter Id of the peer */
 	size_t		diamidlen; /* cached size of the diamid string */
 	DiamId_t	realm;	/* the diameter realm of the peer */
"Welcome to our mercurial repository"